@@ -2,21 +2,23 @@ from .attckobject import AttckObject
 
 
 class AttckMalware(AttckObject):
-    '''A child class of AttckObject
-    
+
+    """Enterprise MITRE ATT&CK Malware object.
+
     Creates objects which have been categorized as malware used in attacks
-    
+
     Example:
-        You can iterate over a `malwares` list and access specific properties and relationship properties.
+        You can iterate over a `malwares` list and access specific properties
+        and relationship properties.
 
         The following relationship properties are accessible:
                 1. actors
                 2. techniques
-        
+
             1. To iterate over an `malwares` list, do the following:
 
             .. code-block:: python
-               
+
                from pyattck import Attck
 
                attck = Attck()
@@ -50,17 +52,19 @@ class AttckMalware(AttckObject):
     Arguments:
         attck_obj (json) -- Takes the raw MITRE ATT&CK Json object
         AttckObject (dict) -- Takes the MITRE ATT&CK Json object as a kwargs values
-    '''
+    """
 
     def __init__(self, attck_obj = None, **kwargs):
-        """This class represents malware as defined with the Enterprise MITRE ATT&CK framework.
+        """
+        This class represents malware as defined by the Enterprise
+        MITRE ATT&CK framework.
 
         Keyword Arguments:
-            attck_obj {json} -- A Enterprise MITRE ATT&CK Framework json object (default: {None})
+            attck_obj {json} -- A Enterprise MITRE ATT&CK Framework
+                                json object (default: {None})
         """
         super(AttckMalware, self).__init__(**kwargs)
         self.__attck_obj = attck_obj
-
         self.id = self._set_id(kwargs)
         self.created_by_ref = self._set_attribute(kwargs, 'created_by_ref')
         self.name = self._set_attribute(kwargs, 'name')
@@ -74,15 +78,16 @@ class AttckMalware(AttckObject):
         self.type = self._set_attribute(kwargs, 'type')
         self.revoked = self._set_attribute(kwargs, 'revoked')
         self.wiki = self._set_wiki(kwargs)
-        
         self.set_relationships(self.__attck_obj)
 
     @property
     def actors(self):
-        """Returns all actor objects as a list that are documented as using this malware
+        """
+        Returns all actor objects as a list that are documented as using this malware
 
         Returns:
-            [list] -- A list of related actor objects defined within the Enterprise MITRE ATT&CK Framework for a malware object
+            [list] -- A list of related actor objects defined within the Enterprise
+                      MITRE ATT&CK Framework for a malware object
         """
         from .actor import AttckActor
         return_list = []
@@ -91,18 +96,20 @@ class AttckMalware(AttckObject):
             if 'type' in item:
                 if item['type'] == 'intrusion-set':
                     item_dict[item['id']] = item
-        
-        for item in self._RELATIONSHIPS[self.stix]:
-            if item in item_dict:
-                return_list.append(AttckActor(**item_dict[item]))
+        if self._RELATIONSHIPS.get(self.stix):
+            for item in self._RELATIONSHIPS[self.stix]:
+                if item in item_dict:
+                    return_list.append(AttckActor(attck_obj=self.__attck_obj, **item_dict[item]))
         return return_list
 
     @property
     def techniques(self):
-        """Returns all technique objects as a list that are documented as using this malware
+        """
+        Returns all technique objects as a list that are documented as using this malware
 
         Returns:
-            [list] -- A list of related technique objects defined within the Enterprise MITRE ATT&CK Framework for a malware object
+            [list] -- A list of related technique objects defined within the
+                      Enterprise MITRE ATT&CK Framework for a malware object
         """
         from .technique import AttckTechnique
         return_list = []
@@ -111,8 +118,8 @@ class AttckMalware(AttckObject):
             if 'type' in item:
                 if item['type'] == 'attack-pattern':
                     item_dict[item['id']] = item
-        
-        for item in self._RELATIONSHIPS[self.stix]:
-            if item in item_dict:
-                return_list.append(AttckTechnique(**item_dict[item]))
-        return return_list
\ No newline at end of file
+        if self._RELATIONSHIPS.get(self.stix):
+            for item in self._RELATIONSHIPS[self.stix]:
+                if item in item_dict:
+                    return_list.append(AttckTechnique(attck_obj=self.__attck_obj, **item_dict[item]))
+        return return_list
