@@ -2,21 +2,25 @@ from .mobileattckobject import MobileAttckObject
 
 
 class MobileAttckMalware(MobileAttckObject):
-    '''A child class of MobileAttckObject
-    
+
+    """Mobile MITRE ATT&CK Malware object.
+
+    A child class of MobileAttckObject
+
     Creates objects which have been categorized as malware used in attacks
-    
+
     Example:
-        You can iterate over a `malwares` list and access specific properties and relationship properties.
+        You can iterate over a `malwares` list and access specific properties
+        and relationship properties.
 
         The following relationship properties are accessible:
                 1. actors
                 2. techniques
-        
+
             1. To iterate over an `malwares` list, do the following:
 
             .. code-block:: python
-               
+
                from pyattck import Attck
 
                attck = Attck()
@@ -46,21 +50,20 @@ class MobileAttckMalware(MobileAttckObject):
                        print(technique.name)
                        print(technique.description)
                        # etc.
-    '''
+    """
 
     def __init__(self, mobile_attck_obj = None, **kwargs):
         """
         Creates an MobileAttckMalware object.  
-        The MobileAttckMalware object is based on malware which have been categorized as software used in attacks
-        
+        The MobileAttckMalware object is based on malware which have been categorized
+        as software used in attacks
+
         Arguments:
             mobile_attck_obj (json) -- Takes the raw MITRE Mobile ATT&CK Json object
             AttckObject (dict) -- Takes the MITRE Mobile ATT&CK Json object as a kwargs values
-
         """
         super(MobileAttckMalware, self).__init__(**kwargs)
         self.__mobile_attck_obj = mobile_attck_obj
-
         self.old_attack_id = self._set_attribute(kwargs, 'x_mitre_old_attack_id')
         self.platforms = self._set_list_items(kwargs, 'x_mitre_platforms')
         self.version = self._set_attribute(kwargs, 'x_mitre_version')
@@ -74,10 +77,13 @@ class MobileAttckMalware(MobileAttckObject):
 
     @property
     def actors(self):
-        """Accessing known actors who have used a piece of malware as part of the MITRE Mobile ATT&CK Framework
+        """
+        Accessing known actors who have used a piece of malware as part of the
+        MITRE Mobile ATT&CK Framework
 
         Returns:
-            list: Returns all actor objects as a list that are documented using a piece of malware
+            list: Returns all actor objects as a list that are documented using a
+                  piece of malware
         """
         from .actor import MobileAttckActor
         return_list = []
@@ -86,10 +92,9 @@ class MobileAttckMalware(MobileAttckObject):
             if 'type' in item:
                 if item['type'] == 'intrusion-set':
                     item_dict[item['id']] = item
-        
         for item in self._RELATIONSHIPS[self.stix]:
             if item in item_dict:
-                return_list.append(MobileAttckActor(**item_dict[item]))
+                return_list.append(MobileAttckActor(mobile_attck_obj=self.__mobile_attck_obj, **item_dict[item]))
         return return_list
 
     @property
@@ -106,8 +111,7 @@ class MobileAttckMalware(MobileAttckObject):
             if 'type' in item:
                 if item['type'] == 'attack-pattern':
                     item_dict[item['id']] = item
-        
         for item in self._RELATIONSHIPS[self.stix]:
             if item in item_dict:
-                return_list.append(MobileAttckTechnique(**item_dict[item]))
-        return return_list
\ No newline at end of file
+                return_list.append(MobileAttckTechnique(mobile_attck_obj=self.__mobile_attck_obj, **item_dict[item]))
+        return return_list
